@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Add 32nd, 64th & odd fractional durations to MIDI-Perl
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0500';
 use strict;
 use warnings;
 
@@ -48,6 +48,12 @@ sub fractional {
     }
 }
 
+
+sub tuple {
+    my ( $duration, $name, $factor ) = @_;
+    $MIDI::Simple::Length{ $name . $duration } = $MIDI::Simple::Length{$duration} / $factor
+}
+
 1;
 
 __END__
@@ -62,7 +68,7 @@ Music::Duration - Add 32nd, 64th & odd fractional durations to MIDI-Perl
 
 =head1 VERSION
 
-version 0.0400
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -85,14 +91,33 @@ L<MIDI::Simple>.  (These are 32nd: y, dy, ddy, ty and 64th: x, dx, ddx, tx.)
 Also, this module allows the addition of non-standard note divisions with the
 B<fractional> function, detailed below.
 
-=head1 FUNCTION
+=head1 FUNCTIONS
 
 =head2 fractional()
 
   Music::Duration::fractional( 'z', 5 )
+  # Then: $score->n( 'zqn', ... );
 
-Add a fractional duration-division (or "tuple") for each duration of the
-L<MIDI::Simple> C<Length> hash.
+Add a fractional division for each duration of the L<MIDI::Simple> C<Length>
+hash.
+
+For the example of 5 divisions, this means that a whole note is 5 beats long.
+The duration for each division is "half as long as the last."  So a half note is
+2 beats long, and a quarter note is, you guessed it - 1.  See the distribution
+test for the full breakdown.
+
+=head2 tuple()
+
+  Music::Duration::tuple( 'wn', 'z', 5 );
+  # Then: $score->n( 'zwn', ... );
+
+Add a fractional division for a given B<duration> of the L<MIDI::Simple>
+C<Length> hash.
+
+Musically, this creates a "cluster" of notes in place of the given B<duration>.
+
+So instead of a whole note of four beats, we instead play 5 beats.  A triplet is
+a 3-tuple.
 
 =head1 SEE ALSO
 
